#
# spec file for package python-gst
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name gst-python

Name:           python-gst
Version:        1.22.9
Release:        1.1
Summary:        Python Bindings for GStreamer
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://gstreamer.freedesktop.org
Source0:        %{url}/src/gst-python/%{_name}-%{version}.tar.xz
# PATCH-FEATURE-OPENSUSE reduce-required-meson.patch -- Fix build on Leap 15.5
Patch0:         reduce-required-meson.patch

BuildRequires:  %{python_module devel}
BuildRequires:  c++_compiler
BuildRequires:  gobject-introspection
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(gstreamer-1.0) >= %{version}
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= %{version}
BuildRequires:  pkgconfig(pygobject-3.0) >= 3.0
Requires:       gstreamer >= %{version}
%{python_subpackages}

%description
This module contains a wrapper that allows GStreamer applications to be
written in Python.

%package -n gstreamer-plugin-python
Summary:        GStreamer 1.0 plugin for python
Group:          System/Libraries

%description -n gstreamer-plugin-python
This module contains a wrapper that allows GStreamer applications to be
written in Python.

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
%{python_expand py_var=$python
  mkdir ../$py_var
  cp -rp * ../$py_var
  pushd ../$py_var
  %meson \
    -Dpython=$py_var \
    %{nil}
  %meson_build
  popd
}

%install
%{python_expand py_var=$python
  pushd ../$py_var
  %meson_install
  popd
}

%files %{python_files}
%license COPYING
%doc NEWS TODO
%dir %{python_sitearch}/gi
%{python_sitearch}/gi/overrides/

%files -n gstreamer-plugin-python
%{_libdir}/gstreamer-1.0/libgstpython.so

%changelog
* Thu Feb  1 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.9:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Thu Jan  4 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.8:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Wed Nov 15 2023 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.7:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Fri Sep 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.6:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Tue Jul 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.5:
  + No changes
- Rebase reduce-required-meson.patch.
* Mon Jun 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.4:
  + python: More functions can be called before gst_init().
- Rebase reduce-required-meson.patch.
* Wed May 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.3:
  + No changes, version bump only.
- Rebase patch.
* Wed Apr 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.2:
  + No changes, version bump only.
- Rebase patch.
* Thu Mar  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.1:
  + gst-python: Use arch-specific install dir for gi overrides
* Thu Mar  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add patch to reduce the required meson version to 0.61.0 since
  that's what we have in Leap 15.5:
  + reduce-required-meson.patch
* Thu Jan 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.0:
  + Please see changes in gstreamer main package, major version
    bump.
* Fri Dec 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.5:
  + No changes, versionbump only.
* Sat Oct 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.4:
  + python: Do not call gst_init when it is already is_initialized.
* Wed Jun 22 2022 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 1.20.3:
  + No changes
* Mon May  9 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.20.2:
  + Fix build on systems without C++ compiler
* Sat Mar 19 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.1:
  + Fix build with Python 3.11.
* Wed Feb  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.0:
  + Fixes for Python 3.10.
  + Various build fixes.
* Fri Feb  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.6:
  + Avoid treating float as int (fix for Python 3.10).
* Wed Sep 15 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.5:
  + No changes
* Wed Jun 30 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.18.4:
  + No changes
* Sat Jan 16 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.3:
  + No changes
* Fri Jan 15 2021 Benjamin Greiner <code@bnavigator.de>
- The happy coincidence that python flavors and their interpreter
  names have the same name is no longer true.
  gh#openSUSE/python-rpm-macros#66
* Thu Dec 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.2:
  + No changes.
* Thu Nov  5 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.18.1:
  + Python 2.x is no longer supported
  + Support mapping buffers without any memcpy:
  * Added a ContextManager to make the API more pythonic with
    buf.map(Gst.MapFlags.READ | Gst.MapFlags.WRITE) as
    info: info.data[42] = 0
  + Added high-level helper API for constructing pipelines:
  * Gst.Bin.make_and_add(factory_name, instance_name=None)
  * Gst.Element.link_many(element, ...)
* Thu Nov  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.18.0:
  + GstTranscoder: new high level API for applications to transcode
    media files from one format to another.
  + High Dynamic Range (HDR) video information representation and
    signalling enhancements.
  + Instant playback rate change support.
  + Active Format Description (AFD) and Bar Data support.
  + RTSP server and client implementations gained ONVIF trick modes
    support.
  + Hardware-accelerated video decoding on Windows via DXVA2 /
    Direct3D11.
  + Microsoft Media Foundation plugin for video capture and
    hardware-accelerated video encoding on Windows.
  + qmlgloverlay: New overlay element that renders a QtQuick scene
    over the top of an input video stream.
  + imagesequencesrc: New element to easily create a video stream
    from a sequence of jpeg or png images.
  + dashsink: New sink to produce DASH content.
  + dvbsubenc: New DVB Subtitle encoder element.
  + MPEG-TS muxing now also supports TV broadcast compliant muxing
    with constant bitrate muxing and SCTE-35 support.
  + rtmp2: New RTMP client source and sink element from-scratch
    implementation.
  + svthevcenc: New SVT-HEVC-based H.265 video encoder.
  + vaapioverlay: New compositor element using VA-API.
  + rtpmanager gained support for Google’s Transport-Wide
    Congestion Control (twcc) RTP extension.
  + splitmuxsink and splitmuxsrc gained support for auxiliary video
    streams.
  + webrtcbin now contains some initial support for renegotiation
    involving stream addition and removal.
  + RTP support was enhanced with new RTP source and sink elements
    to easily set up RTP streaming via rtp:// URIs.
  + avtp: New Audio Video Transport Protocol (AVTP) plugin for
    Time-Sensitive Applications.
  + Support for the Video Services Forum’s Reliable Internet Stream
    Transport (RIST) TR-06-1 Simple Profile.
  + Universal Windows Platform (UWP) support.
  + rpicamsrc: New element for capturing from the Raspberry Pi
    camera.
  + RTSP Server TCP interleaved backpressure handling improvements
    as well as support for Scale/Speed headers.
  + GStreamer Editing Services gained support for nested timelines,
    per-clip speed rate control and the OpenTimelineIO format.
  + Autotools build system has been removed in favour of Meson.
- Drop python-gst-fix-py38-build.patch: fixed upstream.
* Wed Mar 11 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use the singlespec again to properly generate py2 and py3 pkg
* Tue Mar 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add python-gst-fix-py38-build.patch: Fix build with py 3.8.
  Further switch to meson buildsystem, patch only fixes it for
  this, and not autotools. Add c++_compiler and meson BuildRequires
  and meson macros. Drop all python build macros, and add explicit
  pkgconfig(python3) BuildRequires.
- Update URL to new home.
* Mon Feb 17 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Own %%%%{python_sitearch}/gi dir, needed now after changes
  elsewhere in the stack.
* Wed Dec  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.16.2:
  + No changes, version bump only.
* Tue Sep 24 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.16.1:
  + See main gstreamer package for changelog.
* Tue Jun 25 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.16.0:
  + Highlights:
  - GStreamer WebRTC stack gained support for data channels for
    peer-to-peer communication based on SCTP, BUNDLE support,
    as well as support for multiple TURN servers.
  - AV1 video codec support for Matroska and QuickTime/MP4
    containers and more configuration options and supported
    input formats for the AOMedia AV1 encoder
  - Support for Closed Captions and other Ancillary Data in video
  - Support for planar (non-interleaved) raw audio
  - GstVideoAggregator, compositor and OpenGL mixer elements are
    now in -base
  - New alternate fields interlace mode where each buffer carries
    a single field
  - WebM and Matroska ContentEncryption support in the Matroska
    demuxer
  - new WebKit WPE-based web browser source element
  - Video4Linux: HEVC encoding and decoding, JPEG encoding, and
    improved dmabuf import/export
  - Hardware-accelerated Nvidia video decoder gained support for
    VP8/VP9 decoding, whilst the encoder gained support for
    H.265/HEVC encoding.
  - Many improvements to the Intel Media SDK based
    hardware-accelerated video decoder and encoder plugin
    (msdk): dmabuf import/export for zero-copy integration with
    other components; VP9 decoding; 10-bit HEVC encoding; video
    post-processing (vpp) support including deinterlacing; and
    the video decoder now handles dynamic resolution changes.
  - The ASS/SSA subtitle overlay renderer can now handle multiple
    subtitles that overlap in time and will show them on screen
    simultaneously
  - The Meson build is now feature-complete (*) and it is now the
    recommended build system on all platforms. The Autotools
    build is scheduled to be removed in the next cycle.
  - The GStreamer Rust bindings and Rust plugins module are now
    officially part of upstream GStreamer.
  - The GStreamer Editing Services gained a gesdemux element
    that allows directly playing back serialized edit list with
    playbin or (uri)decodebin
  - Many performance improvements.
* Fri May 31 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.14.5:
  + No changes provided by upstream.
* Wed Oct  3 2018 bjorn.lie@gmail.com
- Update to version 1.14.4:
  + Bugfix release, please see .changes in gstreamer main package.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 1.14.3:
  + Bugfix release, please see .changes in gstreamer main package.
* Tue Jul 24 2018 bjorn.lie@gmail.com
- Update to version 1.14.2:
  + No changes, versionbump only.
* Sun May 20 2018 bjorn.lie@gmail.com
- Update to version 1.14.1:
  + GstPad: Fix race condition causing the same probe to be called
    multiple times
  + Fix occasional deadlocks on windows when outputting debug
    logging
  + Fix debug levels being applied in the wrong order
  + GIR annotation fixes for bindings
  + audiomixer, audioaggregator: fix some negotiation issues
  + gst-play-1.0: fix leaving stdin in non-blocking mode after exit
  + flvmux: wait for caps on all input pads before writing header
    even if source is live
  + flvmux: don't wake up the muxer unless there is data, fixes
    busy looping if there's no input data
  + flvmux: fix major leak of input buffers
  + rtspsrc, rtsp-server: revert to RTSP RFC handling of
    sendonly/recvonly attributes
  + rtpvrawpay: fix payloading with very large mtu sizes where
    everything fits into a single RTP packet
  + v4l2: Fix hard-coded enabled v4l2 probe on Linux/ARM
  + v4l2: Disable DMABuf for emulated formats when using libv4l2
  + v4l2: Always set colorimetry in S_FMT
  + asfdemux: Set stream-format field for H264 streams and handle
    H.264 in bytestream format
  + x265enc: Fix tagging of keyframes on output buffers
  + ladspa: Fix critical during plugin load on Windows
  + decklink: Fix COM initialisation on Windows
  + h264parse: fix re-use across pipeline stop/restart
  + mpegtsmux: fix force-keyframe event handling and PCR/PMT
    changes that would confuse some players with generated HLS
    streams
  + adaptivedemux: Support period change in live playlist
  + rfbsrc: Fix support for applevncserver and support NULL pool in
    decide_allocation
  + jpegparse: Fix APP1 marker segment parsing
  + h265parse: Make caps writable before modifying them, fixes
    criticals
  + fakevideosink: request an extra buffer if enable-last-sample is
    enabled
  + wasapisrc: Don't provide a clock based on WASAPI's clock
  + wasapi: Only use audioclient3 when low-latency, as it might
    otherwise glitch with slow CPUs or VMs
  + wasapi: Don't derive device period from latency time, should
    make it more robust against glitches
  + audiolatency: Fix wave detection in buffers and avoid bogus pts
    values while starting
  + msdk: fix plugin load on implementations with only HW support
  + msdk: dec: set framerate to the driver only if provided, not in
    0/1 case
  + msdk: Don't set extended coding options for JPEG encode
  + rtponviftimestamp: fix state change function init/reset causing
    races/crashes on shutdown
  + decklink: fix initialization failure in windows binary
  + ladspa: Fix critical warnings during plugin load on Windows and
    fix dependencies in meson build
  + gl: fix cross-compilation error with viv-fb
  + qmlglsink: make work with eglfs_kms
  + rtspclientsink: Don't deadlock in preroll on early close
  + rtspclientsink: Fix client ports for the RTCP backchannel
  + rtsp-server: Fix session timeout when streaming data to client
    over TCP
  + vaapiencode: h264: find best profile in those available, fixing
    negotiation errors
  + vaapi: remove custom GstGL context handling, use GstGL instead.
    Fixes GL Context sharing with WebkitGtk on wayland
  + gst-editing-services: various fixes
  + gst-python: bump pygobject req to 3.8;
    fix GstPad.set_query_function(); dist autogen.sh and
    configure.ac in tarball
  + g-i: pick up GstVideo-1.0.gir from local build directory in
    GstGL build
  + g-i: update constant values for bindings
  + avoid duplicate symbols in plugins across modules in static
    builds
  + ... and many, many more!
* Tue Apr 17 2018 bjorn.lie@gmail.com
- Update to version 1.14.0:
  + Highlights:
  - WebRTC support: real-time audio/video streaming to and from
    web browsers;
  - Experimental support for the next-gen royalty-free AV1 video
    codec;
  - Video4Linux: encoding support, stable element names and
    faster device probing;
  - Support for the Secure Reliable Transport (SRT) video
    streaming protocol;
  - RTP Forward Error Correction (FEC) support (ULPFEC);
  - RTSP 2.0 support in rtspsrc and gst-rtsp-server;
  - ONVIF audio backchannel support in gst-rtsp-server and
    rtspsrc;
  - playbin3 gapless playback and pre-buffering support;
  - Tee, our stream splitter/duplication element, now does
    allocation query aggregation which is important for efficient
    data handling and zero-copy;
  - QuickTime muxer has a new prefill recording mode that allows
    file import in Adobe Premiere and FinalCut Pro while the file
    is still being written;
  - rtpjitterbuffer fast-start mode and timestamp offset
    adjustment smoothing;
  - souphttpsrc connection sharing, which allows for connection
    reuse, cookie sharing, etc;
  - nvdec: new plugin for hardware-accelerated video decoding
    using the NVIDIA NVDEC API;
  - Adaptive DASH trick play support;
  - ipcpipeline: new plugin that allows splitting a pipeline
    across multiple processes;
  - Major gobject-introspection annotation improvements for large
    parts of the library API;
  - GStreamer C# bindings have been revived and seen many updates
    and fixes;
  - The externally maintained GStreamer Rust bindings had many
    usability improvements and cover most of the API now.
    Coinciding with the 1.14 release, a new release with the 1.14
    API additions is happening.
  + Updated translations.
* Fri Mar 30 2018 bjorn.lie@gmail.com
- Update to version 1.12.5:
  + Bugs fixed: bgo#793560, bgo#793756.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Dec 11 2017 zaitor@opensuse.org
- Update to version 1.12.4:
  + No changes, stable version bump only.
* Mon Sep 18 2017 zaitor@opensuse.org
- Update to version 1.12.3:
  + plugin: Always initialize GIL state.
  + Add support for Gst.Bitmask.
  + tests: Stop using deprecated assertion methods.
  + tests: Move all Fundamental types tests in a file.
  + structure: Add a .keys() method and implement __str__.
  + Return a Gst.*Range instead of a python range converting from
    GValue to python.
  + structures: Override __new__ to make it more pythonic.
  + overrides: Remove IntRange And Int64Range on Python2.
* Fri Jul 14 2017 dimstar@opensuse.org
- Convert to single-spec.
* Fri Jul 14 2017 zaitor@opensuse.org
- Update to version 1.12.2:
  + No changes, stable version bump only.
* Wed Jun 21 2017 zaitor@opensuse.org
- Update to version 1.12.1:
  + No changes, stable version bump only.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 1.12.0:
  + No changes, stable version bump only.
- Changes from version 1.11.91:
  + No changes.
- Changes from version 1.11.90:
  + Bugs fixed: bgo#780369.
* Sat Feb 25 2017 zaitor@opensuse.org
- Update to version 1.11.2:
  + Port old helloworld.py example to GI.
  + python: Add an option to set where to install pygi overrides.
  + meson: bump version and bump meson requirement.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.11.1:
  + Meson build fixes and updates.
  + Play nicely with gst-build uninstalled.
  + common: use https protocol for common submodule.
  + Remove bitrotten and unused gst-python.spec.in file.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.10.4:
  + No changes, versionbump only.
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 1.10.3:
  + No changes, versionbump only.
* Mon Jan  9 2017 dimstar@opensuse.org
- Add gobject-introspection BuildRequires: needed in order to get
  automatic typelib() Requires added to the package (boo#1017473).
* Sat Dec  3 2016 zaitor@opensuse.org
- Update to version 1.10.2:
  + No changes, version bump only.
* Sun Nov 27 2016 zaitor@opensuse.org
- Update to version 1.10.1:
  + No changes, versionbump only.
- Changes from version 1.10.0:
  + Bugs fixed: bgo#772853.
* Wed Aug 24 2016 zaitor@opensuse.org
- Update to version 1.8.3 (boo#996937):
  + No changes, versionbump only.
* Wed Jun 15 2016 zaitor@opensuse.org
- Update to version 1.8.2:
  + No changes, version bump only.
* Thu Apr 21 2016 zaitor@opensuse.org
- Update to version 1.8.1:
  + No changes, version bump only.
* Wed Mar 16 2016 zaitor@opensuse.org
- Update to version 1.8.0:
  + Hardware-accelerated zero-copy video decoding on Android
  + New video capture source for Android using the
    android.hardware.Camera API.
  + Windows Media reverse playback support (ASF/WMV/WMA).
  + New tracing system provides support for more sophisticated
    debugging tools.
  + New high-level GstPlayer playback convenience API.
  + Initial support for the new Vulkan API, see Matthew Waters'
    blog post for more details.
  + Improved Opus audio codec support: Support for more than two
    channels; MPEG-TS demuxer/muxer can now handle Opus;
    sample-accurate encoding/decoding/transmuxing with Ogg,
    Matroska, ISOBMFF (Quicktime/MP4), and MPEG-TS as container;
    new codec utility functions for Opus header and caps handling
    in pbutils library. The Opus encoder/decoder elements were
    also moved to gst-plugins-base (from -bad), and the opus RTP
    depayloader/payloader to -good.
  + GStreamer VAAPI module now released and maintained as part of
    the GStreamer project.
  + Asset proxy support in the GStreamer Editing Services.
- Replace gstreamer-plugins-base-devel for
  pkgconfig(gstreamer-plugins-base-1.0) BuildRequires and version
  it.
- Add explicit pkgconfig(gstreamer-1.0) BuildRequires.
* Sat Feb  6 2016 zaitor@opensuse.org
- Update to version 1.6.2:
  + overrides: fix a few typos in exception messages.
  + python:
  - Check return value of g_module_symbol().
  - Don't call Py_DECREF() on NULL.
  + pythonplugin: Clean up error handling a bit.
* Mon Nov 23 2015 zaitor@opensuse.org
- Update to version 1.6.1:
  + Fix regression creating (Ghost)Pad (bgo#757108).
- Changes from version 1.6.0:
  + tests:
  - Fix tests in python2.
  - Add test_fraction back in the testsuite.
  - Bring back the testsuite and test if the initialization
    override works.
  + overrides:
  - Do not use inspect.signature as it is not avalaible in
    python2.
  - Disable all GStreamer APIs until Gst has been initialized.
  - Try hard to make the query writable in the pad query
    function.
  + Remove INSTALL file.
  + plugin: Name differently between python2 and python3.
* Mon Oct 20 2014 dimstar@opensuse.org
- Update to version 1.4.0:
  + pythonplugin: Fix compiler warning about unused format string
    argument.
* Sat Oct 11 2014 dimstar@opensuse.org
- Update to version 1.3.90:
  + Sync up for releasse with GStreamer 1.4.x.
- Split new subpackage gstreamer-plugin-python, when building for
  python3.
* Thu Sep 11 2014 dimstar@opensuse.org
- Initial package, python gstreamer; bindings for GStreamer 1.0,
  version 1.2.1.
